@@ -12,8 +12,9 @@ use Config::Any;
 use Regexp::Assemble;
 use Scalar::Util qw/ isweak weaken /;
 use Carp qw/ croak /;
+use MRO::Compat;
 
-our $VERSION = '0.04001';
+our $VERSION = '0.04002';
 $VERSION = eval $VERSION;              # see L<perlmodstyle>
 
 __PACKAGE__->mk_accessors(qw( _html_formfu_config ));
@@ -29,7 +30,7 @@ sub build_per_context_instance {
 sub new {
     my $class = shift;
     my ($c)   = @_;
-    my $self  = $class->NEXT::new(@_);
+    my $self  = $class->next::method(@_);
 
     $self->_setup($c);
 
